methodChannel property

  1. @visibleForTesting
MethodChannel methodChannel
final

The method channel used to interact with the native platform.

Implementation

@visibleForTesting
// Must match the channel name registered by the native plugin classes
final methodChannel = const MethodChannel('flutter_live_coverage');